package com.asset.controller;

import com.asset.common.*;
import com.asset.domain.User;
import com.asset.domain.system.Area;
import com.asset.domain.system.Certificate;
import com.asset.domain.system.LoginLog;
import com.asset.mapper.UserMapper;
import com.asset.service.UserService;
import com.asset.service.system.CertificateService;
import com.asset.service.system.LoginLogService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import java.io.UnsupportedEncodingException;
import java.nio.file.spi.FileSystemProvider;


/*
 * @author xiaol
 * @date 2020/03/10
 */
@RestController
public class UserController {

    @Autowired
    UserService userService;

    @Autowired
    CertificateService certificateService;

    @Autowired
    LoginLogService loginLogService;

    @RequestMapping("/register")
    public Result register(@Validated(value={Insert.class}) @RequestBody User user, BindingResult result) throws UnsupportedEncodingException {
        if (result.hasErrors()) {
            return ResultUtil.Validated(result);
        }
        user.setCreateAt(Common.getDate());
        String pass = MD5Util.getEncryption(user.getPassword());
        user.setPassword(pass);
        userService.save(user);
        if(user.getId() != null){
            //组合写入凭证表的数据
            if(user.getExpert() != null){   //专家凭证
                if(user.getExpert().contains(",")){
                    try {
                        certificateService.insertAllCycle(user.getExpert(),user.getId(),1);
                    }catch (Exception e){
                        return ResultUtil.success(CodeEnum.ERROR);
                    }
                }else{
                    try {
                        certificateService.insertCycle(user.getExpert(),user.getId(),1);
                    }catch (Exception e){
                        return ResultUtil.success(CodeEnum.ERROR);
                    }
                }
            }
            if(user.getRecom() != null){      //推荐凭证
                if(user.getRecom().contains(",")){
                    try {
                        certificateService.insertAllCycle(user.getRecom(),user.getId(),2);
                    }catch (Exception e){
                        return ResultUtil.success(CodeEnum.ERROR);
                    }
                }else{
                    try {
                        certificateService.insertCycle(user.getExpert(),user.getId(),2);
                    }catch (Exception e){
                        return ResultUtil.success(CodeEnum.ERROR);
                    }
                }
            }
            if(user.getOther() != null){  //其他凭证
                if(user.getOther().contains(",")){
                    try {
                        certificateService.insertAllCycle(user.getOther(),user.getId(),0);
                    }catch (Exception e){
                        return ResultUtil.success(CodeEnum.ERROR);
                    }
                }else{
                    try {
                        certificateService.insertCycle(user.getExpert(),user.getId(),0);
                    }catch (Exception e){
                        return ResultUtil.success(CodeEnum.ERROR);
                    }
                }
            }
            return ResultUtil.success(CodeEnum.SUCCESS);
        }else{
            return ResultUtil.success(CodeEnum.ERROR);
        }
    }

    @GetMapping("/checkMobile")
    public Result checkMobile(String mobile) {
        if(! Common.isPhone(mobile)){
            return ResultUtil.success(CodeEnum.FORMAT_MOBILE);
        }
        QueryWrapper<User> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("mobile",mobile);
        User admin1 = userService.getOne(queryWrapper);
        if(admin1 != null){
            return ResultUtil.success(CodeEnum.ISEXITE_MOBILE);
        }
        return ResultUtil.success(CodeEnum.SUCCESS);
    }

    @GetMapping("/sendMobileCode")
    public Result sendMobileCode(String mobile) {
        if(! Common.isPhone(mobile)){
            return ResultUtil.success(CodeEnum.FORMAT_MOBILE);
        }

        return ResultUtil.success(CodeEnum.SUCCESS);
    }

    @RequestMapping("/login")
    public Result login(@Validated(value={Login.class}) @RequestBody User user, BindingResult result, HttpSession session, HttpServletRequest request) throws UnsupportedEncodingException {
        if (result.hasErrors()) {
            return ResultUtil.Validated(result);
        }
        String mobile= user.getMobile();
        String password= user.getPassword();
        QueryWrapper<User> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("mobile",mobile);
        User admin1 = userService.getOne(queryWrapper);
        if(admin1 == null){  //判断账号是否存在
            return ResultUtil.error(CodeEnum.ISEXITE_NOT_ERROR);
        }else {
            String pass = MD5Util.getEncryption(password);
            String passwordold = admin1.getPassword();
            if (!passwordold.equals(pass)){
                return ResultUtil.error(CodeEnum.LOGIN_ERROR);
            }
        }
        session.setAttribute("mobile",mobile);
        //登录成功记录登录日志
        LoginLog loginLog = new LoginLog();
        loginLog.setUser_id(admin1.getId().toString());
        loginLog.setIp(Common.getIpAddress(request));
        loginLog.setLogin_create_at(Common.getDate());
        loginLogService.insertLoginLog(loginLog);
        return ResultUtil.success(CodeEnum.SUCCESS);
    }

    @GetMapping("/getUserById")
    public Result getUserById(int id) {
        QueryWrapper<User> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("id",id);
        User user = userService.getOne(queryWrapper);
        if(user != null){
            return ResultUtil.success(CodeEnum.SUCCESS,user);
        }
        return ResultUtil.success(CodeEnum.ERROR);
    }

    @RequestMapping("/getUpdateUser")
    public Result getUpdateUser(@Validated(value={Update.class}) @RequestBody User user, BindingResult result) {
        if (result.hasErrors()) {
            return ResultUtil.Validated(result);
        }
        userService.updateById(user);
        System.out.println(user);
        System.out.println("*****************");
        System.out.println(user.getId());
        if(user.getId() != null){
            //删除凭证的旧数据
            //certificateService.deleteCertificateByUserId(user.getId());
            //组合写入凭证表的数据
            if(user.getExpert() != null){   //专家凭证
                if(user.getExpert().contains(",")){
                    try {
                       // certificateService.insertAllCycle(user.getExpert(),user.getId(),1);
                    }catch (Exception e){
                        return ResultUtil.success(CodeEnum.ERROR);
                    }
                }else{
                    try {
                       // certificateService.insertCycle(user.getExpert(),user.getId(),1);
                    }catch (Exception e){
                        return ResultUtil.success(CodeEnum.ERROR);
                    }
                }
            }
            if(user.getRecom() != null){      //推荐凭证
                if(user.getRecom().contains(",")){
                    try {
                       // certificateService.insertAllCycle(user.getRecom(),user.getId(),2);
                    }catch (Exception e){
                        return ResultUtil.success(CodeEnum.ERROR);
                    }
                }else{
                    try {
                        //certificateService.insertCycle(user.getExpert(),user.getId(),2);
                    }catch (Exception e){
                        return ResultUtil.success(CodeEnum.ERROR);
                    }
                }
            }
            if(user.getOther() != null){  //其他凭证
                if(user.getOther().contains(",")){
                    try {
                        //certificateService.insertAllCycle(user.getOther(),user.getId(),0);
                    }catch (Exception e){
                        return ResultUtil.success(CodeEnum.ERROR);
                    }
                }else{
                    try {
                        //certificateService.insertCycle(user.getExpert(),user.getId(),0);
                    }catch (Exception e){
                        return ResultUtil.success(CodeEnum.ERROR);
                    }
                }
            }
            return ResultUtil.success(CodeEnum.SUCCESS);
        }else{
            return ResultUtil.success(CodeEnum.ERROR);
        }
    }

}
